@@ -3,6 +3,7 @@
     SPDX-FileCopyrightText: 1999 Torben Weis <weis@kde.org>
     SPDX-FileCopyrightText: 2003 Waldo Bastian <bastian@kde.org>
     SPDX-FileCopyrightText: 2012 David Faure <faure@kde.org>
+    SPDX-FileCopyrightText: 2022 Harald Sitter <sitter@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-only
 */
@@ -11,114 +12,24 @@
 #include "kprotocolinfo_p.h"
 #include "kprotocolinfofactory_p.h"
 
+#include "kiocoredebug.h"
+
 #include <KApplicationTrader>
 #include <KConfig>
 #include <KConfigGroup>
+#include <KJsonUtils>
 #include <KPluginMetaData>
 #include <KSharedConfig>
 #include <QUrl>
 
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 84)
-//
-// Internal functions:
-//
-KProtocolInfoPrivate::KProtocolInfoPrivate(const QString &path)
-{
-    KConfig sconfig(path, KConfig::SimpleConfig);
-    KConfigGroup config(&sconfig, "Protocol");
-
-    m_name = config.readEntry("protocol");
-    m_exec = config.readPathEntry("exec", QString());
-    m_isSourceProtocol = config.readEntry("source", true);
-    m_isHelperProtocol = config.readEntry("helper", false);
-    m_supportsReading = config.readEntry("reading", false);
-    m_supportsWriting = config.readEntry("writing", false);
-    m_supportsMakeDir = config.readEntry("makedir", false);
-    m_supportsDeleting = config.readEntry("deleting", false);
-    m_supportsLinking = config.readEntry("linking", false);
-    m_supportsMoving = config.readEntry("moving", false);
-    m_supportsOpening = config.readEntry("opening", false);
-    m_supportsTruncating = config.readEntry("truncating", false);
-    m_canCopyFromFile = config.readEntry("copyFromFile", false);
-    m_canCopyToFile = config.readEntry("copyToFile", false);
-    m_canRenameFromFile = config.readEntry("renameFromFile", false);
-    m_canRenameToFile = config.readEntry("renameToFile", false);
-    m_canDeleteRecursive = config.readEntry("deleteRecursive", false);
-    const QString fnu = config.readEntry("fileNameUsedForCopying", "FromURL");
-    m_fileNameUsedForCopying = KProtocolInfo::FromUrl;
-    if (fnu == QLatin1String("Name")) {
-        m_fileNameUsedForCopying = KProtocolInfo::Name;
-    } else if (fnu == QLatin1String("DisplayName")) {
-        m_fileNameUsedForCopying = KProtocolInfo::DisplayName;
-    }
-
-    m_listing = config.readEntry("listing", QStringList());
-    // Many .protocol files say "Listing=false" when they really mean "Listing=" (i.e. unsupported)
-    if (m_listing.count() == 1 && m_listing.first() == QLatin1String("false")) {
-        m_listing.clear();
-    }
-    m_supportsListing = (m_listing.count() > 0);
-    m_defaultMimetype = config.readEntry("defaultMimetype");
-    m_determineMimetypeFromExtension = config.readEntry("determineMimetypeFromExtension", true);
-    m_archiveMimeTypes = config.readEntry("archiveMimetype", QStringList());
-    m_icon = config.readEntry("Icon");
-    m_config = config.readEntry("config", m_name);
-    m_maxSlaves = config.readEntry("maxInstances", 1);
-    m_maxSlavesPerHost = config.readEntry("maxInstancesPerHost", 0);
-
-    QString tmp = config.readEntry("input");
-    if (tmp == QLatin1String("filesystem")) {
-        m_inputType = KProtocolInfo::T_FILESYSTEM;
-    } else if (tmp == QLatin1String("stream")) {
-        m_inputType = KProtocolInfo::T_STREAM;
-    } else {
-        m_inputType = KProtocolInfo::T_NONE;
-    }
-
-    tmp = config.readEntry("output");
-    if (tmp == QLatin1String("filesystem")) {
-        m_outputType = KProtocolInfo::T_FILESYSTEM;
-    } else if (tmp == QLatin1String("stream")) {
-        m_outputType = KProtocolInfo::T_STREAM;
-    } else {
-        m_outputType = KProtocolInfo::T_NONE;
-    }
-
-    m_docPath = config.readPathEntry("X-DocPath", QString());
-    if (m_docPath.isEmpty()) {
-        m_docPath = config.readPathEntry("DocPath", QString());
-    }
-    m_protClass = config.readEntry("Class").toLower();
-    if (!m_protClass.startsWith(QLatin1Char(':'))) {
-        m_protClass.prepend(QLatin1Char(':'));
-    }
-
-    const QStringList extraNames = config.readEntry("ExtraNames", QStringList());
-    const QStringList extraTypes = config.readEntry("ExtraTypes", QStringList());
-    QStringList::const_iterator it = extraNames.begin();
-    QStringList::const_iterator typeit = extraTypes.begin();
-    for (; it != extraNames.end() && typeit != extraTypes.end(); ++it, ++typeit) {
-        QVariant::Type type = QVariant::nameToType((*typeit).toLatin1().constData());
-        // currently QVariant::Type and ExtraField::Type use the same subset of values, so we can just cast.
-        m_extraFields.append(KProtocolInfo::ExtraField(*it, static_cast<KProtocolInfo::ExtraField::Type>(type)));
-    }
-
-    m_showPreviews = config.readEntry("ShowPreviews", m_protClass == QLatin1String(":local"));
-
-    m_capabilities = config.readEntry("Capabilities", QStringList());
-
-    m_slaveHandlesNotify = config.readEntry("slaveHandlesNotify", QStringList());
-
-    m_proxyProtocol = config.readEntry("ProxiedBy");
-}
-#endif
-
 KProtocolInfoPrivate::KProtocolInfoPrivate(const QString &name, const QString &exec, const QJsonObject &json)
     : m_name(name)
     , m_exec(exec)
 {
     // source has fallback true if not set
     m_isSourceProtocol = json.value(QStringLiteral("source")).toBool(true);
+    // true if not set for backwards compatibility
+    m_supportsPermissions = json.value(QStringLiteral("permissions")).toBool(true);
 
     // other bools are fine with default false by toBool
     m_isHelperProtocol = json.value(QStringLiteral("helper")).toBool();
@@ -164,10 +75,10 @@ KProtocolInfoPrivate::KProtocolInfoPrivate(const QString &name, const QString &e
     // config has fallback to name if not set
     m_config = json.value(QStringLiteral("config")).toString(m_name);
 
-    // max slaves has fallback to 1 if not set
-    m_maxSlaves = json.value(QStringLiteral("maxInstances")).toInt(1);
+    // max workers has fallback to 1 if not set
+    m_maxWorkers = json.value(QStringLiteral("maxInstances")).toInt(1);
 
-    m_maxSlavesPerHost = json.value(QStringLiteral("maxInstancesPerHost")).toInt();
+    m_maxWorkersPerHost = json.value(QStringLiteral("maxInstancesPerHost")).toInt();
 
     QString tmp = json.value(QStringLiteral("input")).toString();
     if (tmp == QLatin1String("filesystem")) {
@@ -198,15 +109,19 @@ KProtocolInfoPrivate::KProtocolInfoPrivate(const QString &name, const QString &e
     }
 
     // ExtraNames is a translated value, use the KCoreAddons helper to read it
-    const QStringList extraNames = KPluginMetaData::readTranslatedValue(json, QStringLiteral("ExtraNames")).toVariant().toStringList();
-
+    const QStringList extraNames = KJsonUtils::readTranslatedValue(json, QStringLiteral("ExtraNames")).toVariant().toStringList();
     const QStringList extraTypes = json.value(QStringLiteral("ExtraTypes")).toVariant().toStringList();
-    QStringList::const_iterator it = extraNames.begin();
-    QStringList::const_iterator typeit = extraTypes.begin();
-    for (; it != extraNames.end() && typeit != extraTypes.end(); ++it, ++typeit) {
-        QVariant::Type type = QVariant::nameToType((*typeit).toLatin1().constData());
-        // currently QVariant::Type and ExtraField::Type use the same subset of values, so we can just cast.
-        m_extraFields.append(KProtocolInfo::ExtraField(*it, static_cast<KProtocolInfo::ExtraField::Type>(type)));
+    if (extraNames.size() == extraTypes.size()) {
+        auto func = [](const QString &name, const QString &type) {
+            const int metaType = QMetaType::fromName(type.toLatin1().constData()).id();
+            // currently QMetaType::Type and ExtraField::Type use the same subset of values, so we can just cast.
+            return KProtocolInfo::ExtraField(name, static_cast<KProtocolInfo::ExtraField::Type>(metaType));
+        };
+
+        std::transform(extraNames.cbegin(), extraNames.cend(), extraTypes.cbegin(), std::back_inserter(m_extraFields), func);
+    } else {
+        qCWarning(KIO_CORE) << "Malformed JSON protocol file for protocol:" << name
+                            << ", number of the ExtraNames fields should match the number of ExtraTypes fields";
     }
 
     // fallback based on class
@@ -214,8 +129,6 @@ KProtocolInfoPrivate::KProtocolInfoPrivate(const QString &name, const QString &e
 
     m_capabilities = json.value(QStringLiteral("Capabilities")).toVariant().toStringList();
 
-    m_slaveHandlesNotify = json.value(QStringLiteral("slaveHandlesNotify")).toVariant().toStringList();
-
     m_proxyProtocol = json.value(QStringLiteral("ProxiedBy")).toString();
 }
 
@@ -265,24 +178,24 @@ QString KProtocolInfo::config(const QString &_protocol)
     return QStringLiteral("kio_%1rc").arg(prot->m_config);
 }
 
-int KProtocolInfo::maxSlaves(const QString &_protocol)
+int KProtocolInfo::maxWorkers(const QString &_protocol)
 {
     KProtocolInfoPrivate *prot = KProtocolInfoFactory::self()->findProtocol(_protocol);
     if (!prot) {
         return 1;
     }
 
-    return prot->m_maxSlaves;
+    return prot->m_maxWorkers;
 }
 
-int KProtocolInfo::maxSlavesPerHost(const QString &_protocol)
+int KProtocolInfo::maxWorkersPerHost(const QString &_protocol)
 {
     KProtocolInfoPrivate *prot = KProtocolInfoFactory::self()->findProtocol(_protocol);
     if (!prot) {
         return 0;
     }
 
-    return prot->m_maxSlavesPerHost;
+    return prot->m_maxWorkersPerHost;
 }
 
 bool KProtocolInfo::determineMimetypeFromExtension(const QString &_protocol)
@@ -349,7 +262,7 @@ bool KProtocolInfo::showFilePreview(const QString &_protocol)
     KProtocolInfoPrivate *prot = KProtocolInfoFactory::self()->findProtocol(_protocol);
     const bool defaultSetting = prot ? prot->m_showPreviews : false;
 
-    KConfigGroup group(KSharedConfig::openConfig(), "PreviewSettings");
+    KConfigGroup group(KSharedConfig::openConfig(), QStringLiteral("PreviewSettings"));
     return group.readEntry(_protocol, defaultSetting);
 }
 
@@ -373,16 +286,6 @@ QStringList KProtocolInfo::archiveMimetypes(const QString &protocol)
     return prot->m_archiveMimeTypes;
 }
 
-QStringList KProtocolInfo::slaveHandlesNotify(const QString &_protocol)
-{
-    KProtocolInfoPrivate *prot = KProtocolInfoFactory::self()->findProtocol(_protocol);
-    if (!prot) {
-        return QStringList();
-    }
-
-    return prot->m_slaveHandlesNotify;
-}
-
 QString KProtocolInfo::proxiedBy(const QString &_protocol)
 {
     KProtocolInfoPrivate *prot = KProtocolInfoFactory::self()->findProtocol(_protocol);
@@ -418,9 +321,9 @@ bool KProtocolInfo::isKnownProtocol(const QUrl &url)
     return isKnownProtocol(url.scheme());
 }
 
-bool KProtocolInfo::isKnownProtocol(const QString &protocol)
+bool KProtocolInfo::isKnownProtocol(const QString &protocol, bool updateCacheIfNotfound)
 {
     // We call the findProtocol (const QString&) to bypass any proxy settings.
-    KProtocolInfoPrivate *prot = KProtocolInfoFactory::self()->findProtocol(protocol);
+    KProtocolInfoPrivate *prot = KProtocolInfoFactory::self()->findProtocol(protocol, updateCacheIfNotfound);
     return prot;
 }
