@@ -708,12 +708,16 @@ static bool isSubCommand(int cmd)
 
 void SlaveBase::mimeType(const QString &_type)
 {
-    // qDebug() << _type;
-    int cmd;
+    qCDebug(KIO_CORE) << "detected mimetype" << _type;
+    int cmd = CMD_NONE;
     do {
+        if (wasKilled()) {
+            break;
+        }
+
         // Send the meta-data each time we send the MIME type.
         if (!mOutgoingMetaData.isEmpty()) {
-            // qDebug() << "emitting meta data";
+            qCDebug(KIO_CORE) << "sending mimetype meta data";
             KIO_DATA << mOutgoingMetaData;
             send(INF_META_DATA, data);
         }
@@ -726,10 +730,11 @@ void SlaveBase::mimeType(const QString &_type)
                 ret = d->appConnection.read(&cmd, data);
             }
             if (ret == -1) {
-                // qDebug() << "read error";
+                qCDebug(KIO_CORE) << "read error on app connection while sending mimetype";
                 exit();
+                break;
             }
-            // qDebug() << "got" << cmd;
+            qCDebug(KIO_CORE) << "got reply after sending mimetype" << cmd;
             if (cmd == CMD_HOST) { // Ignore.
                 continue;
             }
@@ -1476,6 +1481,7 @@ void SlaveBase::send(int cmd, const QByteArray &arr)
             slaveWriteError = true;
         }
         if (slaveWriteError) {
+            qCWarning(KIO_CORE) << "An error occurred during write. The worker terminates now.";
             exit();
         }
     }
