@@ -107,13 +107,6 @@ void WorkerBase::dataReq()
     d->bridge.dataReq();
 }
 
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 103)
-void WorkerBase::needSubUrlData()
-{
-    d->bridge.needSubUrlData();
-}
-#endif
-
 void WorkerBase::workerStatus(const QString &host, bool connected)
 {
     d->bridge.slaveStatus(host, connected);
@@ -316,11 +309,6 @@ WorkerResult WorkerBase::chown(QUrl const &, const QString &, const QString &)
     return WorkerResult::fail(ERR_UNSUPPORTED_ACTION, unsupportedActionErrorString(d->protocolName(), CMD_CHOWN));
 }
 
-WorkerResult WorkerBase::multiGet(const QByteArray &)
-{
-    return WorkerResult::fail(ERR_UNSUPPORTED_ACTION, unsupportedActionErrorString(d->protocolName(), CMD_MULTI_GET));
-}
-
 WorkerResult WorkerBase::fileSystemFreeSpace(const QUrl &)
 {
     return WorkerResult::fail(ERR_UNSUPPORTED_ACTION, unsupportedActionErrorString(d->protocolName(), CMD_FILESYSTEMFREESPACE));
@@ -356,6 +344,11 @@ int WorkerBase::messageBox(const QString &text,
     return d->bridge.messageBox(text, static_cast<SlaveBase::MessageBoxType>(type), title, primaryActionText, secondaryActionText, dontAskAgainName);
 }
 
+int WorkerBase::sslError(const QVariantMap &sslData)
+{
+    return d->bridge.sslError(sslData);
+}
+
 bool WorkerBase::canResume(KIO::filesize_t offset)
 {
     return d->bridge.canResume(offset);
