@@ -425,6 +425,7 @@ void KNewFileMenuPrivate::initDialog()
     m_fileDialog->setAttribute(Qt::WA_DeleteOnClose);
     m_fileDialog->setModal(m_modal);
     m_fileDialog->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum);
+    m_fileDialog->setWindowTitle(i18nc("@title:window", "Create New File"));
 
     m_messageWidget = new KMessageWidget(m_fileDialog);
     m_messageWidget->setCloseButtonVisible(false);
@@ -738,7 +739,7 @@ void KNewFileMenuPrivate::fillMenu()
                         // Both actions have now the same shortcut, so this will prevent the "Ambiguous shortcut detected" dialog.
                         act->setShortcutContext(Qt::WidgetShortcut);
                         // We also need to react to shortcut changes.
-                        QObject::connect(m_newFolderShortcutAction, &QAction::changed, act, [=]() {
+                        QObject::connect(m_newFolderShortcutAction, &QAction::changed, act, [act, this]() {
                             act->setShortcuts(m_newFolderShortcutAction->shortcuts());
                         });
                     }
@@ -812,7 +813,7 @@ void KNewFileMenuPrivate::fillMenu()
                                 // Both actions have now the same shortcut, so this will prevent the "Ambiguous shortcut detected" dialog.
                                 act->setShortcutContext(Qt::WidgetShortcut);
                                 // We also need to react to shortcut changes.
-                                QObject::connect(m_newFileShortcutAction, &QAction::changed, act, [=]() {
+                                QObject::connect(m_newFileShortcutAction, &QAction::changed, act, [act, this]() {
                                     act->setShortcuts(m_newFileShortcutAction->shortcuts());
                                 });
                             }
@@ -1416,7 +1417,7 @@ void KNewFileMenu::createDirectory()
     d->m_baseUrl = d->m_popupFiles.first();
 
     auto nameJob = new KIO::NameFinderJob(d->m_baseUrl, name, this);
-    connect(nameJob, &KJob::result, this, [=]() mutable {
+    connect(nameJob, &KJob::result, this, [nameJob, name, this]() mutable {
         if (!nameJob->error()) {
             d->m_baseUrl = nameJob->baseUrl();
             name = nameJob->finalName();
@@ -1430,7 +1431,7 @@ void KNewFileMenuPrivate::showNewDirNameDlg(const QString &name)
 {
     initDialog();
 
-    m_fileDialog->setWindowTitle(i18nc("@title:window", "New Folder"));
+    m_fileDialog->setWindowTitle(i18nc("@title:window", "Create New Folder"));
 
     m_label->setText(i18n("Create new folder in %1:", m_baseUrl.toDisplayString(QUrl::PreferLocalFile)));
 
@@ -1494,10 +1495,9 @@ void KNewFileMenu::setSupportedMimeTypes(const QStringList &mime)
 void KNewFileMenu::slotResult(KJob *job)
 {
     if (job->error()) {
-        if (job->error() == KIO::ERR_DIR_ALREADY_EXIST) {
+        if (job->error() == KIO::ERR_DIR_ALREADY_EXIST && d->m_selectDirWhenAlreadyExists) {
             auto *simpleJob = ::qobject_cast<KIO::SimpleJob *>(job);
             if (simpleJob) {
-                Q_ASSERT(d->m_selectDirWhenAlreadyExists);
                 const QUrl jobUrl = simpleJob->url();
                 // Select the existing dir
                 Q_EMIT selectExistingDir(jobUrl);
