@@ -42,33 +42,11 @@ class KNewFileMenuPrivate;
  * @author David Faure <faure@kde.org>
  * Ideas and code for the new template handling mechanism ('link' desktop files)
  * from Christoph Pickart <pickart@iam.uni-bonn.de>
- * @since 4.5
  */
 class KIOFILEWIDGETS_EXPORT KNewFileMenu : public KActionMenu
 {
     Q_OBJECT
 public:
-#if KIOFILEWIDGETS_ENABLE_DEPRECATED_SINCE(5, 100)
-    /**
-     * Constructor.
-     * @param collection the KActionCollection the QAction with name @p name should be added to.
-     * @param name action name, when adding the action to @p collection
-     * @param parent the parent object, for ownership.
-     * If the parent object is a widget, it will also used as parent widget
-     * for any dialogs that this class might show. Otherwise, call setParentWidget.
-     * @note If you want the "Create directory..." action shortcut to show up next to its text,
-     *       make sure to have an action with name "create_dir" (and shortcut set) in @p collection.
-     *       This will only work with KIO >= 5.27.
-     *       From KIO >= 5.53, an action named "create_file" (and shortcut set) in @p collection
-     *       will be linked to the creation of the first file template (either from XDG_TEMPLATES_DIR
-     *       or from :/kio5/newfile-templates)
-     * @deprecated since 5.100, use KNewFileMenu(QObject *) instead. To associate the action shortcuts use
-     * setNewFileShortcutAction() and setNewFolderShortcutAction()
-     */
-    KIOFILEWIDGETS_DEPRECATED_VERSION(5, 100, "Use KNewFileMenu(QObject *)")
-    KNewFileMenu(KActionCollection *collection, const QString &name, QObject *parent);
-#endif
-
     /**
      * Constructor.
      *
@@ -93,15 +71,6 @@ public:
      */
     bool isModal() const;
 
-#if KIOFILEWIDGETS_ENABLE_DEPRECATED_SINCE(5, 97)
-    /**
-     * Returns the files that the popup is shown for
-     * @deprecated since 5.97, use KNewFileMenu::workingDirectory().
-     */
-    KIOFILEWIDGETS_DEPRECATED_VERSION(5, 97, "Use KNewFileMenu::workingDirectory()")
-    QList<QUrl> popupFiles() const;
-#endif
-
     /**
      * Sets the modality of dialogs created by KNewFile. Set to false if you do not want to block
      * your application window when entering a new directory name i.e.
@@ -114,16 +83,6 @@ public:
      */
     void setParentWidget(QWidget *parentWidget);
 
-#if KIOFILEWIDGETS_ENABLE_DEPRECATED_SINCE(5, 97)
-    /**
-     * Set the files the popup is shown for
-     * Call this before showing up the menu
-     * @deprecated since 5.97, use KNewFileMenu::setWorkingDirectory(const QUrl &).
-     */
-    KIOFILEWIDGETS_DEPRECATED_VERSION(5, 97, "Use KNewFileMenu::setWorkingDirectory(const QUrl &)")
-    void setPopupFiles(const QList<QUrl> &files);
-#endif
-
     /**
      * Set the working directory.
      * Files will be created relative to this directory.
@@ -138,14 +97,6 @@ public:
      */
     QUrl workingDirectory() const;
 
-#if KIOFILEWIDGETS_ENABLE_DEPRECATED_SINCE(5, 0)
-    KIOFILEWIDGETS_DEPRECATED_VERSION(5, 0, "Use KNewFileMenu::setWorkingDirectory(const QUrl &)")
-    void setPopupFiles(const QUrl &file)
-    {
-        setWorkingDirectory(file);
-    }
-#endif
-
     /**
      * Only show the files in a given set of MIME types.
      * This is useful in specialized applications (while file managers, on
@@ -153,15 +104,6 @@ public:
      */
     void setSupportedMimeTypes(const QStringList &mime);
 
-#if KIOFILEWIDGETS_ENABLE_DEPRECATED_SINCE(5, 97)
-    KIOFILEWIDGETS_DEPRECATED_VERSION(5, 97, "Calling this has no effect")
-    /**
-     * Set if the directory view currently shows dot files.
-     * @deprecated since 5.97. Calling this has no effect.
-     */
-    void setViewShowsHiddenFiles(bool b);
-#endif
-
     /**
      * Returns the MIME types set in supportedMimeTypes()
      */
