@@ -15,7 +15,7 @@
 #include "kurlnavigatordropdownbutton_p.h"
 #include "kurlnavigatorpathselectoreventfilter_p.h"
 #include "kurlnavigatorplacesselector_p.h"
-#include "kurlnavigatorprotocolcombo_p.h"
+#include "kurlnavigatorschemecombo_p.h"
 #include "kurlnavigatortogglebutton_p.h"
 
 #include <KIO/StatJob>
@@ -47,8 +47,6 @@
 using namespace KDEPrivate;
 
 struct KUrlNavigatorData {
-    QUrl rootUrl; // KF6: remove after the deprecated methods have been removed
-    QPoint pos; // KF6: remove after the deprecated methods have been removed
     QByteArray state;
 };
 Q_DECLARE_METATYPE(KUrlNavigatorData)
@@ -77,7 +75,7 @@ public:
     bool slotCheckFilters(const QString &text);
 
     void slotReturnPressed();
-    void slotProtocolChanged(const QString &);
+    void slotSchemeChanged(const QString &);
     void openPathSelectorMenu();
 
     /**
@@ -168,11 +166,11 @@ public:
     QHBoxLayout *m_layout = new QHBoxLayout(q);
     KCoreUrlNavigator *m_coreUrlNavigator = nullptr;
     QList<KUrlNavigatorButton *> m_navButtons;
-    QStringList m_customProtocols;
+    QStringList m_supportedSchemes;
     QUrl m_homeUrl;
     KUrlNavigatorPlacesSelector *m_placesSelector = nullptr;
     KUrlComboBox *m_pathBox = nullptr;
-    KUrlNavigatorProtocolCombo *m_protocols = nullptr;
+    KUrlNavigatorSchemeCombo *m_schemes = nullptr;
     KUrlNavigatorDropDownButton *m_dropDownButton = nullptr;
     KUrlNavigatorButtonBase *m_toggleEditableMode = nullptr;
     QWidget *m_dropWidget = nullptr;
@@ -231,10 +229,10 @@ KUrlNavigatorPrivate::KUrlNavigatorPrivate(const QUrl &url, KUrlNavigator *qq, K
         q->connect(placesModel, &KFilePlacesModel::dataChanged, q, updateContentFunc);
     }
 
-    // create protocol combo
-    m_protocols = new KUrlNavigatorProtocolCombo(QString(), q);
-    q->connect(m_protocols, &KUrlNavigatorProtocolCombo::activated, q, [this](const QString &protocol) {
-        slotProtocolChanged(protocol);
+    // create scheme combo
+    m_schemes = new KUrlNavigatorSchemeCombo(QString(), q);
+    q->connect(m_schemes, &KUrlNavigatorSchemeCombo::activated, q, [this](const QString &schene) {
+        slotSchemeChanged(schene);
     });
 
     // create drop down button for accessing all paths of the URL
@@ -255,7 +253,7 @@ KUrlNavigatorPrivate::KUrlNavigatorPrivate(const QUrl &url, KUrlNavigator *qq, K
     m_pathBox->setAutoDeleteCompletionObject(true);
 
     // TODO KF6: remove this QOverload, only KUrlComboBox::returnPressed(const QString &) will remain
-    q->connect(m_pathBox, qOverload<const QString &>(&KUrlComboBox::returnPressed), q, [this]() {
+    q->connect(m_pathBox, &KUrlComboBox::returnPressed, q, [this]() {
         slotReturnPressed();
     });
     q->connect(m_pathBox, &KUrlComboBox::urlActivated, q, &KUrlNavigator::setLocationUrl);
@@ -275,7 +273,7 @@ KUrlNavigatorPrivate::KUrlNavigatorPrivate(const QUrl &url, KUrlNavigator *qq, K
     if (m_placesSelector != nullptr) {
         m_layout->addWidget(m_placesSelector);
     }
-    m_layout->addWidget(m_protocols);
+    m_layout->addWidget(m_schemes);
     m_layout->addWidget(m_dropDownButton);
     m_layout->addWidget(m_pathBox, 1);
     m_layout->addWidget(m_toggleEditableMode);
@@ -299,7 +297,7 @@ void KUrlNavigatorPrivate::slotApplyUrl(QUrl url)
     // SPDX-FileCopyrightText: 2001 Joseph Wenninger <jowenn@kde.org>
     // SPDX-FileCopyrightText: 2001 Anders Lund <anders.lund@lund.tdcadsl.dk>
 
-    // For example "desktop:/" _not_ "desktop:", see the comment in slotProtocolChanged()
+    // For example "desktop:/" _not_ "desktop:", see the comment in slotSchemeChanged()
     if (!url.isEmpty() && url.path().isEmpty() && KProtocolInfo::protocolClass(url.scheme()) == QLatin1String(":local")) {
         url.setPath(QStringLiteral("/"));
     }
@@ -354,7 +352,7 @@ void KUrlNavigatorPrivate::applyUncommittedUrl()
 
     // Dirs and symlinks to dirs
     constexpr auto details = KIO::StatBasic | KIO::StatResolveSymlink;
-    auto *job = KIO::statDetails(url, KIO::StatJob::DestinationSide, details, KIO::HideProgressInfo);
+    auto *job = KIO::stat(url, KIO::StatJob::DestinationSide, details, KIO::HideProgressInfo);
     q->connect(job, &KJob::result, q, [this, job, text]() {
         // If there is a dir matching "text" relative to the current url, use that, e.g.:
         // - typing "bar" while at "/path/to/foo" ---> "/path/to/foo/bar/"
@@ -391,13 +389,13 @@ void KUrlNavigatorPrivate::slotReturnPressed()
     }
 }
 
-void KUrlNavigatorPrivate::slotProtocolChanged(const QString &protocol)
+void KUrlNavigatorPrivate::slotSchemeChanged(const QString &scheme)
 {
     Q_ASSERT(m_editable);
 
     QUrl url;
-    url.setScheme(protocol);
-    if (KProtocolInfo::protocolClass(protocol) == QLatin1String(":local")) {
+    url.setScheme(scheme);
+    if (KProtocolInfo::protocolClass(scheme) == QLatin1String(":local")) {
         // E.g. "file:/" or "desktop:/", _not_ "file:" or "desktop:" respectively.
         // This is the more expected behaviour, "file:somedir" treats somedir as
         // a path relative to current dir; file:/somedir is an absolute path to /somedir.
@@ -607,13 +605,13 @@ void KUrlNavigatorPrivate::openContextMenu(const QPoint &p)
 void KUrlNavigatorPrivate::slotPathBoxChanged(const QString &text)
 {
     if (text.isEmpty()) {
-        const QString protocol = q->locationUrl().scheme();
-        m_protocols->setProtocol(protocol);
-        if (m_customProtocols.count() != 1) {
-            m_protocols->show();
+        const QString scheme = q->locationUrl().scheme();
+        m_schemes->setScheme(scheme);
+        if (m_supportedSchemes.count() != 1) {
+            m_schemes->show();
         }
     } else {
-        m_protocols->hide();
+        m_schemes->hide();
     }
 }
 
@@ -625,7 +623,7 @@ void KUrlNavigatorPrivate::updateContent()
     }
 
     if (m_editable) {
-        m_protocols->hide();
+        m_schemes->hide();
         m_dropDownButton->hide();
 
         deleteButtons();
@@ -637,7 +635,7 @@ void KUrlNavigatorPrivate::updateContent()
     } else {
         m_pathBox->hide();
 
-        m_protocols->hide();
+        m_schemes->hide();
 
         m_toggleEditableMode->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Preferred);
         q->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
@@ -757,8 +755,8 @@ void KUrlNavigatorPrivate::updateButtonVisibility()
         availableWidth -= m_placesSelector->width();
     }
 
-    if ((m_protocols != nullptr) && m_protocols->isVisible()) {
-        availableWidth -= m_protocols->width();
+    if ((m_schemes != nullptr) && m_schemes->isVisible()) {
+        availableWidth -= m_schemes->width();
     }
 
     // Check whether buttons must be hidden at all...
@@ -1083,32 +1081,6 @@ void KUrlNavigator::setFocus()
     }
 }
 
-#if KIOFILEWIDGETS_BUILD_DEPRECATED_SINCE(4, 5)
-void KUrlNavigator::setUrl(const QUrl &url)
-{
-    // deprecated
-    setLocationUrl(url);
-}
-#endif
-
-#if KIOFILEWIDGETS_BUILD_DEPRECATED_SINCE(4, 5)
-void KUrlNavigator::saveRootUrl(const QUrl &url)
-{
-    auto current = d->m_coreUrlNavigator->locationState().value<KUrlNavigatorData>();
-    current.rootUrl = url;
-    d->m_coreUrlNavigator->saveLocationState(QVariant::fromValue(current));
-}
-#endif
-
-#if KIOFILEWIDGETS_BUILD_DEPRECATED_SINCE(4, 5)
-void KUrlNavigator::savePosition(int x, int y)
-{
-    auto current = d->m_coreUrlNavigator->locationState().value<KUrlNavigatorData>();
-    current.pos = QPoint(x, y);
-    d->m_coreUrlNavigator->saveLocationState(QVariant::fromValue(current));
-}
-#endif
-
 void KUrlNavigator::keyPressEvent(QKeyEvent *event)
 {
     if (isUrlEditable() && (event->key() == Qt::Key_Escape)) {
@@ -1205,15 +1177,15 @@ KUrlComboBox *KUrlNavigator::editor() const
     return d->m_pathBox;
 }
 
-void KUrlNavigator::setCustomProtocols(const QStringList &protocols)
+void KUrlNavigator::setSupportedSchemes(const QStringList &schemes)
 {
-    d->m_customProtocols = protocols;
-    d->m_protocols->setCustomProtocols(d->m_customProtocols);
+    d->m_supportedSchemes = schemes;
+    d->m_schemes->setSupportedSchemes(d->m_supportedSchemes);
 }
 
-QStringList KUrlNavigator::customProtocols() const
+QStringList KUrlNavigator::supportedSchemes() const
 {
-    return d->m_customProtocols;
+    return d->m_supportedSchemes;
 }
 
 QWidget *KUrlNavigator::dropWidget() const
@@ -1241,63 +1213,4 @@ bool KUrlNavigator::sortHiddenFoldersLast() const
     return d->m_subfolderOptions.sortHiddenLast;
 }
 
-#if KIOFILEWIDGETS_BUILD_DEPRECATED_SINCE(4, 5)
-const QUrl &KUrlNavigator::url() const
-{
-    // deprecated
-
-    // Workaround required because of flawed interface ('const QUrl&' is returned
-    // instead of 'QUrl'): remember the URL to prevent a dangling pointer
-    static QUrl url;
-    url = locationUrl();
-    return url;
-}
-#endif
-
-#if KIOFILEWIDGETS_BUILD_DEPRECATED_SINCE(4, 5)
-QUrl KUrlNavigator::url(int index) const
-{
-    // deprecated
-    return d->buttonUrl(index);
-}
-#endif
-
-#if KIOFILEWIDGETS_BUILD_DEPRECATED_SINCE(4, 5)
-QUrl KUrlNavigator::historyUrl(int historyIndex) const
-{
-    // deprecated
-    return locationUrl(historyIndex);
-}
-#endif
-
-#if KIOFILEWIDGETS_BUILD_DEPRECATED_SINCE(4, 5)
-const QUrl &KUrlNavigator::savedRootUrl() const
-{
-    // deprecated
-    // Workaround required because of flawed interface ('const QUrl&' is returned
-    // instead of 'QUrl'): remember the root URL to prevent a dangling pointer
-    static QUrl rootUrl;
-    const auto current = d->m_coreUrlNavigator->locationState().value<KUrlNavigatorData>();
-    rootUrl = current.rootUrl;
-    return rootUrl;
-}
-#endif
-
-#if KIOFILEWIDGETS_BUILD_DEPRECATED_SINCE(4, 5)
-QPoint KUrlNavigator::savedPosition() const
-{
-    // deprecated
-    const auto current = d->m_coreUrlNavigator->locationState().value<KUrlNavigatorData>();
-    return current.pos;
-}
-#endif
-
-#if KIOFILEWIDGETS_BUILD_DEPRECATED_SINCE(4, 5)
-void KUrlNavigator::setHomeUrl(const QString &homeUrl)
-{
-    // deprecated
-    setLocationUrl(QUrl::fromUserInput(homeUrl));
-}
-#endif
-
 #include "moc_kurlnavigator.cpp"
