@@ -4,11 +4,10 @@
 
 class ScopedProcessRunner : public ForkingProcessRunner
 {
-  Q_OBJECT
+    Q_OBJECT
 public:
     explicit ScopedProcessRunner();
-private Q_SLOTS:
-    void slotProcessStarted() override;
+    void startProcess() override;
 };
 
 #endif // SCOPEDPROCESSRUNNER_H
