@@ -31,6 +31,7 @@
 #include <KLocalizedString>
 
 #include <authinfo.h>
+#include <ksslcertificatemanager.h>
 
 // Pseudo plugin class to embed meta data
 class KIOPluginForMetaData : public QObject
@@ -124,7 +125,22 @@ void HTTPProtocol::handleSslErrors(QNetworkReply *reply, const QList<QSslError>
 
     auto sslErrors = errors;
 
-    // const QList<QSslCertificate> peerCertificateChain = socket.peerCertificateChain();
+    const QList<QSslError> fatalErrors = KSslCertificateManager::nonIgnorableErrors(sslErrors);
+    if (!fatalErrors.isEmpty()) {
+        qCWarning(KIOHTTP_LOG) << "SSL errors that cannot be ignored occured" << fatalErrors;
+        Q_EMIT errorOut(KIO::ERR_CANNOT_CONNECT);
+        return;
+    }
+
+    KSslCertificateRule rule = KSslCertificateManager::self()->rule(certs.first(), m_hostName);
+
+    // remove previously seen and acknowledged errors
+    const QList<QSslError> remainingErrors = rule.filterErrors(sslErrors);
+    if (remainingErrors.isEmpty()) {
+        reply->ignoreSslErrors();
+        return;
+    }
+
     // try to fill in the blanks, i.e. missing certificates, and just assume that
     // those belong to the peer (==website or similar) certificate.
     for (int i = 0; i < sslErrors.count(); i++) {
@@ -164,6 +180,30 @@ void HTTPProtocol::handleSslErrors(QNetworkReply *reply, const QList<QSslError>
     int result = sslError(sslData);
 
     if (result == 1) {
+        QDateTime ruleExpiry = QDateTime::currentDateTime();
+
+        const int result = messageBox(WarningTwoActionsCancel,
+                                      i18n("Would you like to accept this "
+                                           "certificate forever without "
+                                           "being prompted?"),
+                                      i18n("Server Authentication"),
+                                      i18n("&Forever"),
+                                      i18n("&Current Session only"));
+        if (result == WorkerBase::PrimaryAction) {
+            // accept forever ("for a very long time")
+            ruleExpiry = ruleExpiry.addYears(1000);
+        } else if (result == WorkerBase::SecondaryAction) {
+            // accept "for a short time", half an hour.
+            ruleExpiry = ruleExpiry.addSecs(30 * 60);
+        } else {
+            Q_EMIT errorOut(KIO::ERR_CANNOT_CONNECT);
+            return;
+        }
+
+        rule.setExpiryDateTime(ruleExpiry);
+        rule.setIgnoredErrors(sslErrors);
+        KSslCertificateManager::self()->setRule(rule);
+
         reply->ignoreSslErrors();
     } else {
         Q_EMIT errorOut(KIO::ERR_CANNOT_CONNECT);
